@@ -163,7 +163,7 @@ private Q_SLOTS:
             qApp->activeWindow()->close();
         });
 
-        QFileDialog::getSaveFileUrl(0, QString(), url);
+        QFileDialog::getSaveFileUrl(nullptr, QString(), url);
 
         QCOMPARE(saveFileOperationMode, KFileWidget::Saving);
     }
@@ -347,37 +347,6 @@ private Q_SLOTS:
         QTRY_VERIFY(timerRun);
     }
 
-    void testRememberLastDirectory()
-    {
-        const QUrl dir = QUrl::fromLocalFile(QDir::tempPath()).adjusted(QUrl::StripTrailingSlash);
-        // Open and navigate
-        {
-            QFileDialog dialog;
-            dialog.open();
-
-            KFileWidget *fw = findFileWidget();
-            QVERIFY(fw);
-            // real show() is delayed to next event.
-            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
-            QCOMPARE(fw->isVisible(), true);
-            fw->setUrl(dir);
-            fw->slotCancel();
-        }
-        // Open another filedialog, check that the default directory is the one from above
-        {
-            QFileDialog dialog;
-            dialog.open();
-
-            KFileWidget *fw = findFileWidget();
-            QVERIFY(fw);
-            // real show() is delayed to next event.
-            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
-            QCOMPARE(fw->isVisible(), true);
-            QCOMPARE(dialog.directoryUrl().adjusted(QUrl::StripTrailingSlash), dir);
-            fw->slotCancel();
-        }
-    }
-
 private:
     QTemporaryDir m_tempDir;
 
@@ -408,7 +377,7 @@ private:
             }
         }
         Q_ASSERT(widgets.count() == 1);
-        return (widgets.count() == 1) ? widgets.first() : Q_NULLPTR;
+        return (widgets.count() == 1) ? widgets.first() : nullptr;
     }
 
     static QDialog *findMessageBox()
@@ -420,7 +389,7 @@ private:
                 widgets.append(dlg);
             }
         }
-        return (widgets.count() == 1) ? widgets.first() : Q_NULLPTR;
+        return (widgets.count() == 1) ? widgets.first() : nullptr;
     }
 };
 
